@@ -163,21 +163,30 @@ def dataset(data_id, key="*"):
     return api.dataset(data_id=data_id, key=key)
 
 
-def connect(transcriptic_path="~/.transcriptic"):
+def connect(transcriptic_path="~/.transcriptic", mocked=False):
     """
     Instantiates a Connection based on the specified path, and overwrites the
     existing `api` object with this Connection
 
     Parameters
     ----------
-    transcriptic_path:
-     Path to transcriptic dot-file
+    transcriptic_path
+        Path to transcriptic dot-file
+    mocked
+        If specified, instantiates a mocked connection
     """
     # TODO: Mirror login code from CLI
-    try:
-        api = Connection.from_file(transcriptic_path)
-    except (OSError, IOError):
-        print(
-            "Unable to find .transcriptic file, please ensure the right path"
-            " is provided"
-        )
+    if mocked is True:
+        from transcriptic.sampledata.connection import MockConnection
+
+        api = MockConnection()
+        return api
+    else:
+        try:
+            api = Connection.from_file(transcriptic_path)
+            return api
+        except (OSError, IOError):
+            print(
+                "Unable to find .transcriptic file, please ensure the right path"
+                " is provided"
+            )
